@@ -201,10 +201,15 @@ class EnchantCell(EnchantBase):
         return cell
 
     @staticmethod
-    def fill_color(cell, color):
+    def fill_color(cell, color, fill_type="solid", **kwargs):
         """ 封装一些我自己常用的填色方案 """
         from openpyxl.styles import PatternFill
-        cell.fill = PatternFill(fgColor=color.hex[-6:], fill_type="solid")
+        from pyxllib.cv.rgbfmt import RgbFormatter
+        if isinstance(color, str):
+            color = RgbFormatter.from_name(color)
+        elif isinstance(color, (list, tuple)):
+            color = RgbFormatter(*color)
+        cell.fill = PatternFill(fgColor=color.to_hex()[1:], fill_type=fill_type, **kwargs)
 
 
 EnchantCell.enchant()
